Learn R Programming

cn.farms (version 1.20.0)

dnaCopySf: Runs DNAcopy in parallel mode

Description

This function even works very well with ff matrices,

Usage

dnaCopySf(x, chrom, maploc, cores = 1, smoothing, ...)

Arguments

x
A matrix with data of the copy number experiments
chrom
The chromosomes (or other group identifier) from which the markers came
maploc
The locations of marker on the genome
cores
Number of cores to use
smoothing
States if smoothing of the data should be done
...
Further parameter for the function segment of DNAcopy

Value

An instance of ExpressionSet containing the segments.

Examples

Run this code
load(system.file("exampleData/mlData.RData", package = "cn.farms"))
mlData <- mlData[, 1:3]
colnames(assayData(mlData)$L_z) <- sampleNames(mlData)
segments <- dnaCopySf(
        x         = assayData(mlData)$L_z,
        chrom     = fData(mlData)$chrom,
        maploc    = fData(mlData)$start,
        cores     = 1,
        smoothing = FALSE)
fData(segments)

Run the code above in your browser using DataLab