Learn R Programming

cn.farms (version 1.20.0)

doCnFarmsSingle: Does the whole cn.farms process in one call

Description

Works for all kind of Affymetrix SNP arrays

Usage

doCnFarmsSingle(celfiles, samplenames, normalization)

Arguments

celfiles
The celfiles which you want to process with the whole path. Either a vector or a matrix with two columns for combined analysis e.g. 500K Array.
samplenames
An optional vector with the same dimension as the number of cel files
normalization
The normalization method you want to use.

Value

The ready cn.FARMS results.