Learn R Programming

cn.farms (version 1.20.0)

summarizeFarmsExact: Summarization Laplacian approach with exact computation

Description

This function implements an exact Laplace FARMS algorithm.

Usage

summarizeFarmsExact(probes, mu = 1, weight = 0.001, weightSignal = 1, weightZ = 1, weightProbes = TRUE, cyc = c(10, 10), tol = 1e-05, weightType = "mean", centering = "median", rescale = FALSE, backscaleComputation = FALSE, maxIntensity = TRUE, refIdx, ...)

Arguments

probes
A matrix with numeric values.
mu
Hyperparameter value which allows to quantify different aspects of potential prior knowledge. Values near zero assumes that most positions do not contain a signal, and introduces a bias for loading matrix elements near zero. Default value is 0 and it's recommended not to change it.
weight
Hyperparameter value which determines the influence of the Gaussian prior of the loadings
weightSignal
Hyperparameter value on the signal.
weightZ
Hyperparameter value which determines how strong the Laplace prior of the factor should be at 0. Users should be aware, that a change of weightZ in comparison to the default parameter might also entail a need to change other parameters. Unexperienced users should not change weightZ.
weightProbes
Parameter (TRUE/FALSE), that determines, if the number of probes should additionally be considered in weight. If TRUE, weight will be modified.
cyc
Number of cycles. If the length is two, it is assumed, that a minimum and a maximum number of cycles is given. If the length is one, the value is interpreted as the exact number of cycles to be executed (minimum == maximum).
tol
States the termination tolerance if cyc[1]!=cyc[2]. Default is 0.00001.
weightType
Flag, that is used to summarize the probes of a sample.
centering
States how the data should be centered ("mean", "median"). Default is median.
rescale
Parameter (TRUE/FALSE), that determines, if moments in exact Laplace FARMS are rescaled in each iteration. Default is FALSE.
backscaleComputation
Parameter (TRUE/FALSE), that determines if the moments of hidden variables should be reestimated after rescaling the parameters.
maxIntensity
Parameter (TRUE/FALSE), that determines if the expectation value (=FALSE) or the maximum value (=TRUE) of p(z|x_i) should be used for an estimation of the hidden varaible.
refIdx
index or indices which are used for computation of the centering
...
Further parameters for expert users.

Value

A list including: the found parameters: lambda0, lambda1, Psithe estimated factors: z (expectation), maxZ (maximum)p: log-likelihood of the data given the found lambda0, lambda1, Psi (not the posterior likelihood that is optimized)varzx: variances of the hidden variables given the dataKL: Kullback Leibler divergences between between posterior and prior distribution of the hidden variablesIC: Information Content considering the hidden variables and dataICtransform: transformed Information ContentCase: Case for computation of a sample point (non-exception, special exception)L1median: Median of the lambda vector componentsintensity: back-computed summarized probeset values with mean correctionL_z: back-computed summarized probeset values without mean correctionrawCN: transformed values of L_zSNR: some additional signal to noise ratio value

Examples

Run this code
x <- matrix(rnorm(100, 11), 20, 5)
summarizeFarmsExact(x)

Run the code above in your browser using DataLab